Implements assignment of polygon values to the target frame using different assignment rules. For efficient performance implemented using SQL.
geomerge.assign(polygon_input,target,assignment,population.data,optional.inputs,silent)Returns an object of class data.frame that contains the column from input, after proper assignment, that is to be added to target@data.
input SpatialPolygonsDataFrame parsed from geomerge main function.
SpatialPolygonsDataFrame representing desired units of analysis. See Details of geomerge.
identification of either population- or area-weighting assignment rules when handling SpatialPolygonsDataFrame joins to target. Default = "max(area)". See Details in geomerge.
specifies data used for weighting if a population-based assignment rule is selected. See Details in geomerge.
Any optional inputs compatible with the extract function in terra.
Boolean switch to suppress any (non-critical) warnings and messages. Default = FALSE.
Karsten Donnay and Andrew M. Linke.
For details on different input parameters, please refer to the detailed documentation in geomerge.
Andrew M. Linke, Karsten Donnay. (2017). "Scale Variability Misclassification: The Impact of Spatial Resolution on Effect Estimates in the Geographic Analysis of Foreign Aid and Conflict." Paper presented at the International Studies Association Annual Meeting, February 22-25 2017, Baltimore.
geomerge-package, geomerge, generateGrid