Nigeria administrative units (ADM1) dataset used as example for the target SpatialPolygonsDataFrame data are merged. The dataset is available at http://www.arcgis.com/home/item.html?id=0e58995046b74254911c1dc0eb756fa4.
data(geomerge)A SpatialPolygonsDataFrame containing observation and that data is merged to using geomerge.
Note that the polygons in counties have been simplified to reduced the size of the target SpatialPolygonsDataFrame for easier illustration. This applies, in particular, to the Niger Delta region of Nigeria.
Andrew M. Linke, Karsten Donnay. (2017). "Scale Variability Misclassification: The Impact of Spatial Resolution on Effect Estimates in the Geographic Analysis of Foreign Aid and Conflict." Paper presented at the International Studies Association Annual Meeting, February 22-25 2017, Baltimore.