Learn R Programming

geomerge (version 0.3.0)

geoEPR: Polygon dataset to illustrate the functionality of geomerge

Description

geoEPR Nigeria dataset used as example for a SpatialPolygonsDataFrame available from https://icr.ethz.ch/data/epr/geoepr/. The dataset contains geo-locations for all politically relevant ethnic groups from the EPR-Core 2014 dataset. It assigns every politically relevant group one of six settlement patterns and provides polygons describing their location.

Usage

data(geomerge)

Arguments

Format

A SpatialPolygonsDataFrame containing observations.

References

Andrew M. Linke, Karsten Donnay. (2017). "Scale Variability Misclassification: The Impact of Spatial Resolution on Effect Estimates in the Geographic Analysis of Foreign Aid and Conflict." Paper presented at the International Studies Association Annual Meeting, February 22-25 2017, Baltimore.